@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::Multext;
 use strict;
 use warnings;
-our $VERSION = '3.012';
+our $VERSION = '3.013';
 
 use utf8;
 use open ':utf8';
@@ -585,7 +585,8 @@ sub _create_atoms
         {
             'd' => 'digit',
             'r' => 'roman',
-            'l' => 'word'
+            'l' => 'word',
+            'm' => 'combi' # combined digits + suffix, e.g. 7-oji, 2009-ųjų
         },
         # We cannot say that 'l' is default. It would work for Czech, Slovenian and Croatian.
         # However, it would not work for Romanian where we distinguish collective numerals ("both").
@@ -826,16 +827,20 @@ sub _create_atoms
             'f' => ['foreign' => 'yes'],
             # typo
             't' => ['typo' => 'yes'],
+            # symbol (occurs in Lithuanian as Xh)
+            'h' => ['pos' => 'sym'],
             # program
             # DZ: I am not sure what this value is supposed to mean. It is mentioned but not explained in the documentation.
             # It does not occur in the SETimes.HR corpus.
             'p' => []
         },
         'encode_map' =>
-
-            { 'foreign' => { 'yes' => 'f',
-                             '@'       => { 'typo' => { 'yes' => 't',
-                                                        '@'    => '-' }}}}
+        {
+            'pos' => { 'sym' => 'h',
+                       '@'   => { 'foreign' => { 'yes' => 'f',
+                                                 '@'       => { 'typo' => { 'yes' => 't',
+                                                                            '@'    => '-' }}}}}
+        }
     );
     return \%atoms;
 }
@@ -946,7 +951,7 @@ Lingua::Interset::Tagset::Multext - Common code for drivers of tagsets of the Mu
 
 =head1 VERSION
 
-version 3.012
+version 3.013
 
 =head1 SYNOPSIS
 
@@ -1027,7 +1032,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
+This software is copyright (c) 2019 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
